# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAccountResult',
    'AwaitableGetAccountResult',
    'get_account',
    'get_account_output',
]

@pulumi.output_type
class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, droplet_limit=None, email=None, email_verified=None, floating_ip_limit=None, id=None, status=None, status_message=None, uuid=None):
        if droplet_limit and not isinstance(droplet_limit, int):
            raise TypeError("Expected argument 'droplet_limit' to be a int")
        pulumi.set(__self__, "droplet_limit", droplet_limit)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if email_verified and not isinstance(email_verified, bool):
            raise TypeError("Expected argument 'email_verified' to be a bool")
        pulumi.set(__self__, "email_verified", email_verified)
        if floating_ip_limit and not isinstance(floating_ip_limit, int):
            raise TypeError("Expected argument 'floating_ip_limit' to be a int")
        pulumi.set(__self__, "floating_ip_limit", floating_ip_limit)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if status_message and not isinstance(status_message, str):
            raise TypeError("Expected argument 'status_message' to be a str")
        pulumi.set(__self__, "status_message", status_message)
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        pulumi.set(__self__, "uuid", uuid)

    @_builtins.property
    @pulumi.getter(name="dropletLimit")
    def droplet_limit(self) -> _builtins.int:
        """
        The total number of droplets current user or team may have active at one time.
        """
        return pulumi.get(self, "droplet_limit")

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        """
        The email address used by the current user to register for DigitalOcean.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> _builtins.bool:
        """
        If true, the user has verified their account via email. False otherwise.
        """
        return pulumi.get(self, "email_verified")

    @_builtins.property
    @pulumi.getter(name="floatingIpLimit")
    def floating_ip_limit(self) -> _builtins.int:
        """
        The total number of floating IPs the current user or team may have.
        """
        return pulumi.get(self, "floating_ip_limit")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        This value is one of "active", "warning" or "locked".
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> _builtins.str:
        """
        A human-readable message giving more details about the status of the account.
        """
        return pulumi.get(self, "status_message")

    @_builtins.property
    @pulumi.getter
    def uuid(self) -> _builtins.str:
        """
        The unique universal identifier for the current user.
        """
        return pulumi.get(self, "uuid")


class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            droplet_limit=self.droplet_limit,
            email=self.email,
            email_verified=self.email_verified,
            floating_ip_limit=self.floating_ip_limit,
            id=self.id,
            status=self.status,
            status_message=self.status_message,
            uuid=self.uuid)


def get_account(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountResult:
    """
    Get information on your DigitalOcean account.

    ## Example Usage

    Get the account:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_account()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult).value

    return AwaitableGetAccountResult(
        droplet_limit=pulumi.get(__ret__, 'droplet_limit'),
        email=pulumi.get(__ret__, 'email'),
        email_verified=pulumi.get(__ret__, 'email_verified'),
        floating_ip_limit=pulumi.get(__ret__, 'floating_ip_limit'),
        id=pulumi.get(__ret__, 'id'),
        status=pulumi.get(__ret__, 'status'),
        status_message=pulumi.get(__ret__, 'status_message'),
        uuid=pulumi.get(__ret__, 'uuid'))
def get_account_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountResult]:
    """
    Get information on your DigitalOcean account.

    ## Example Usage

    Get the account:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_account()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult)
    return __ret__.apply(lambda __response__: GetAccountResult(
        droplet_limit=pulumi.get(__response__, 'droplet_limit'),
        email=pulumi.get(__response__, 'email'),
        email_verified=pulumi.get(__response__, 'email_verified'),
        floating_ip_limit=pulumi.get(__response__, 'floating_ip_limit'),
        id=pulumi.get(__response__, 'id'),
        status=pulumi.get(__response__, 'status'),
        status_message=pulumi.get(__response__, 'status_message'),
        uuid=pulumi.get(__response__, 'uuid')))
